@@ -14,15 +14,12 @@
 
 using namespace std;
 
-FileInfo::FileInfo(const string &input, const string &output)
- : ParserInfo(input), input_file_name(strip_file_path(input)),
-   output_file_name(output), output_file_extension("."+get_file_extension(output))
-{
+FileInfo::FileInfo(const string &input, const string &output) :
+    ParserInfo(input), input_file_name(strip_file_path(input)),
+            output_file_name(output), output_file_extension("."
+                    +get_file_extension(output)) {
 }
 
-
-FileInfo::~FileInfo()
-{
+FileInfo::~FileInfo() {
 }
 
-
