@@ -1,5 +1,5 @@
 /*
-*   $Id: readtags.c,v 1.2 2005-10-15 15:03:35 bettini Exp $
+*   $Id: readtags.c,v 1.3 2008-06-05 18:03:55 bettini Exp $
 *
 *   Copyright (c) 1996-2003, Darren Hiebert
 *
@@ -453,6 +453,10 @@ static tagFile *initialize (const char *const filePath, tagFileInfo *const info)
 	result->fp = fopen (filePath, "r");
 	if (result->fp == NULL)
 	{
+	    /* added by Lorenzo Bettini, to avoid memory leaks */
+	    free (result->line.buffer);
+	    free (result->name.buffer);
+	    free (result->fields.list);
 	    free (result);
 	    result = NULL;
 	    info->status.error_number = errno;
