@@ -130,24 +130,27 @@
 #include <iostream>
 #include <string>
 
-#include "generatorfactory.h"
+#include "textstyleformatterfactory.h"
 #include "colors.h"
 #include "keys.h"
-#include "messages.h"
 #include "parsestyles.h"
 #include "fileutil.h"
 #include "stylekey.h"
 #include "utils.h"
+#include "parserexception.h"
 
 using std::cerr;
 
+extern int line;
+
 static int yyparse() ;
 static void yyerror( char *s ) ;
+static void yyerror( const string &s ) ;
 
 // line is defined in styleparser
 
-// to generate the generator for each language element
-static GeneratorFactory *generatorFactory;
+// to generate the formatter for each language element
+static TextStyleFormatterFactory *formatterFactory;
 
 static void updateBgColor(const std::string &c);
 
@@ -165,6 +168,9 @@ static string currentColor;
 /// the global pointer to the current bg color
 static string currentBGColor;
 
+/// where we store possible errors
+static string errorBuffer;
+
 
 
 /* Enabling traces.  */
@@ -187,7 +193,7 @@ static string currentBGColor;
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 63 "./stylecssparser.yy"
+#line 69 "./stylecssparser.yy"
 {
   int tok ; /* command */
   const std::string * string ; /* string : id, ... */
@@ -196,7 +202,7 @@ typedef union YYSTYPE
   KeyList *keylist;
 }
 /* Line 187 of yacc.c.  */
-#line 200 "stylecssparser.cc"
+#line 206 "stylecssparser.cc"
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
@@ -209,7 +215,7 @@ typedef union YYSTYPE
 
 
 /* Line 216 of yacc.c.  */
-#line 213 "stylecssparser.cc"
+#line 219 "stylecssparser.cc"
 
 #ifdef short
 # undef short
@@ -498,9 +504,9 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,    78,    78,    79,    82,    83,    86,    90,    89,   134,
-     140,   148,   149,   152,   153,   154,   157,   162,   169,   174,
-     181,   182,   183,   184,   185,   186
+       0,    89,    89,    90,    93,    94,    97,   101,   100,   142,
+     148,   156,   157,   160,   161,   162,   165,   170,   177,   182,
+     189,   190,   191,   192,   193,   194
 };
 #endif
 
@@ -1108,6 +1114,46 @@ yydestruct (yymsg, yytype, yyvaluep)
 
   switch (yytype)
     {
+      case 9: /* "KEY" */
+#line 82 "./stylecssparser.yy"
+	{
+	if ((yyvaluep->string))
+	  delete (yyvaluep->string);
+};
+#line 1124 "stylecssparser.cc"
+	break;
+      case 10: /* "COLOR" */
+#line 82 "./stylecssparser.yy"
+	{
+	if ((yyvaluep->string))
+	  delete (yyvaluep->string);
+};
+#line 1132 "stylecssparser.cc"
+	break;
+      case 11: /* "BG_COLOR" */
+#line 82 "./stylecssparser.yy"
+	{
+	if ((yyvaluep->string))
+	  delete (yyvaluep->string);
+};
+#line 1140 "stylecssparser.cc"
+	break;
+      case 12: /* "STRINGDEF" */
+#line 82 "./stylecssparser.yy"
+	{
+	if ((yyvaluep->string))
+	  delete (yyvaluep->string);
+};
+#line 1148 "stylecssparser.cc"
+	break;
+      case 22: /* "keylist" */
+#line 82 "./stylecssparser.yy"
+	{
+	if ((yyvaluep->keylist))
+	  delete (yyvaluep->keylist);
+};
+#line 1156 "stylecssparser.cc"
+	break;
 
       default:
 	break;
@@ -1415,15 +1461,15 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 78 "./stylecssparser.yy"
+#line 89 "./stylecssparser.yy"
     { /* allow empty files */ }
     break;
 
   case 7:
-#line 90 "./stylecssparser.yy"
+#line 101 "./stylecssparser.yy"
     {
-               printSequence( (yyvsp[(1) - (1)].keylist) ) ;
-               printMessage_noln( ": " ) ;
+               //printSequence( $1 ) ;
+               //printMessage_noln( ": " ) ;
                currentStyleConstants = StyleConstantsPtr(new StyleConstants);
                currentColor = "";
                currentBGColor = "";
@@ -1431,13 +1477,8 @@ yyreduce:
     break;
 
   case 8:
-#line 98 "./stylecssparser.yy"
+#line 109 "./stylecssparser.yy"
     {
-               printMessage_noln(" color: " + currentColor + " ") ;
-               if (currentBGColor != "")
-                  printMessage_noln(" bg color: " + currentBGColor + " ") ;
-               printMessage("");
-
                KeyType key;
                KeyList *keylist = (yyvsp[(1) - (4)].keylist);
                for (KeyList::const_iterator it = keylist->begin(); it != keylist->end(); ++it) {
@@ -1452,15 +1493,17 @@ yyreduce:
 
                   // avoid adding an empty style definition for normal
                   if (currentColor != "" || currentStyleConstants->size()) {
-                    if (!generatorFactory->createGenerator(NORMAL, currentColor, "", currentStyleConstants)) {
-                      parseStyleError(key);
-                      yyerror("already defined");
+                    if (!formatterFactory->createFormatter(NORMAL, currentColor, "", currentStyleConstants)) {
+                      errorBuffer = "already defined " NORMAL;
+                      delete keylist;
+                      YYERROR;
                     }
                   }
                 } else {
-                      if (!generatorFactory->createGenerator(key, currentColor, currentBGColor, currentStyleConstants)) {
-                      parseStyleError(key);
-                      yyerror("already defined");
+                  if (!formatterFactory->createFormatter(key, currentColor, currentBGColor, currentStyleConstants)) {
+                      errorBuffer = "already defined " + key;
+                      delete keylist;
+                      YYERROR;
                   }
                 }
                }
@@ -1469,7 +1512,7 @@ yyreduce:
     break;
 
   case 9:
-#line 135 "./stylecssparser.yy"
+#line 143 "./stylecssparser.yy"
     {
               (yyvsp[(1) - (3)].keylist)->push_back(*(yyvsp[(3) - (3)].string));
               (yyval.keylist) = (yyvsp[(1) - (3)].keylist);
@@ -1478,7 +1521,7 @@ yyreduce:
     break;
 
   case 10:
-#line 141 "./stylecssparser.yy"
+#line 149 "./stylecssparser.yy"
     {
               (yyval.keylist) = new KeyList;
               (yyval.keylist)->push_back(*(yyvsp[(1) - (1)].string));
@@ -1487,12 +1530,12 @@ yyreduce:
     break;
 
   case 11:
-#line 148 "./stylecssparser.yy"
+#line 156 "./stylecssparser.yy"
     {}
     break;
 
   case 16:
-#line 158 "./stylecssparser.yy"
+#line 166 "./stylecssparser.yy"
     {
           currentColor = *(yyvsp[(1) - (1)].string);
           delete (yyvsp[(1) - (1)].string);
@@ -1500,7 +1543,7 @@ yyreduce:
     break;
 
   case 17:
-#line 163 "./stylecssparser.yy"
+#line 171 "./stylecssparser.yy"
     {
           currentColor = *(yyvsp[(1) - (1)].string);
           delete (yyvsp[(1) - (1)].string);
@@ -1508,7 +1551,7 @@ yyreduce:
     break;
 
   case 18:
-#line 170 "./stylecssparser.yy"
+#line 178 "./stylecssparser.yy"
     {
           currentBGColor = *(yyvsp[(1) - (1)].string);
           delete (yyvsp[(1) - (1)].string);
@@ -1516,7 +1559,7 @@ yyreduce:
     break;
 
   case 19:
-#line 175 "./stylecssparser.yy"
+#line 183 "./stylecssparser.yy"
     {
           currentBGColor = *(yyvsp[(1) - (1)].string);
           delete (yyvsp[(1) - (1)].string);
@@ -1524,38 +1567,38 @@ yyreduce:
     break;
 
   case 20:
-#line 181 "./stylecssparser.yy"
-    { printMessage_noln( " bold" ) ; currentStyleConstants->push_back(ISBOLD); }
+#line 189 "./stylecssparser.yy"
+    { currentStyleConstants->push_back(ISBOLD); }
     break;
 
   case 21:
-#line 182 "./stylecssparser.yy"
-    { printMessage_noln( " italics" ) ; currentStyleConstants->push_back(ISITALIC); }
+#line 190 "./stylecssparser.yy"
+    { currentStyleConstants->push_back(ISITALIC); }
     break;
 
   case 22:
-#line 183 "./stylecssparser.yy"
-    { printMessage_noln( " underline" ) ; currentStyleConstants->push_back(ISUNDERLINE); }
+#line 191 "./stylecssparser.yy"
+    { currentStyleConstants->push_back(ISUNDERLINE); }
     break;
 
   case 23:
-#line 184 "./stylecssparser.yy"
-    { printMessage_noln( " fixed" ) ; currentStyleConstants->push_back(ISFIXED); }
+#line 192 "./stylecssparser.yy"
+    { currentStyleConstants->push_back(ISFIXED); }
     break;
 
   case 24:
-#line 185 "./stylecssparser.yy"
-    { printMessage_noln( " notfixed" ) ; currentStyleConstants->push_back(ISNOTFIXED); }
+#line 193 "./stylecssparser.yy"
+    { currentStyleConstants->push_back(ISNOTFIXED); }
     break;
 
   case 25:
-#line 186 "./stylecssparser.yy"
-    { printMessage_noln( " noref" ) ; currentStyleConstants->push_back(ISNOREF); }
+#line 194 "./stylecssparser.yy"
+    { currentStyleConstants->push_back(ISNOREF); }
     break;
 
 
 /* Line 1267 of yacc.c.  */
-#line 1559 "stylecssparser.cc"
+#line 1602 "stylecssparser.cc"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1769,43 +1812,53 @@ yyreturn:
 }
 
 
-#line 189 "./stylecssparser.yy"
+#line 197 "./stylecssparser.yy"
 
 
 // string current_file; defined in styleparser
 
 extern string current_file;
 
-void parseCssStyles(const string &path, const string &name, GeneratorFactory *genFactory,
+void parseCssStyles(const string &path, const string &name, TextStyleFormatterFactory *genFactory,
                    string &bodyBgColor_)
 {
-  generatorFactory = genFactory;
+  formatterFactory = genFactory;
+  errorBuffer = "";
+  int result = 1;
+  line = 1;
+
   // opens the file for yylex
   stylecsssc_in = open_data_file_stream(path, name);
 
-  current_file = (path.size() ? path + "/" : "") + name;
-
-  printMessage_noln( "Parsing ", cerr ) ;
-  printMessage_noln (current_file, cerr);
-  printMessage( " file ...", cerr ) ;
+  if (contains_path(name))
+    current_file = name;
+  else
+    current_file = (path.size() ? path + "/" : "") + name;
 
   bodyBgColor = "";
 
-  yyparse() ;
+  result = yyparse() ;
 
   bodyBgColor_ = bodyBgColor;
 
-  printMessage( "Parsing done!", cerr ) ;
   fclose(stylecsssc_in);
 
   // release scanner memory
   stylecsssc_lex_destroy();
+  
+  if (result != 0 || errorBuffer.size()) {
+  	throw ParserException(errorBuffer, current_file, line);
+  }
 }
 
 void
 yyerror( char *s )
 {
-  parseStyleError(s);
+  errorBuffer = s;
+}
+
+void yyerror(const string &s) {
+  yyerror(s.c_str());
 }
 
 void updateBgColor(const std::string &c)
