@@ -84,8 +84,8 @@
      COLOR = 265,
      BG_COLOR = 266,
      STRINGDEF = 267,
-     BODY_BG_COLOR = 268,
-     BG_T = 269
+     BG_T = 268,
+     BODY_BG_COLOR = 269
    };
 #endif
 /* Tokens.  */
@@ -99,8 +99,8 @@
 #define COLOR 265
 #define BG_COLOR 266
 #define STRINGDEF 267
-#define BODY_BG_COLOR 268
-#define BG_T 269
+#define BG_T 268
+#define BODY_BG_COLOR 269
 
 
 
@@ -132,18 +132,20 @@
 #include <iostream>
 #include <string>
 
-#include "generatorfactory.h"
+#include "textstyleformatterfactory.h"
 #include "colors.h"
 #include "keys.h"
-#include "messages.h"
 #include "parsestyles.h"
 #include "fileutil.h"
 #include "stylekey.h"
+#include "parserexception.h"
 
 using std::cerr;
+using std::string;
 
 static int yyparse() ;
 static void yyerror( char *s ) ;
+static void yyerror( const string &s ) ;
 
 int line = 1 ;
 
@@ -155,8 +157,11 @@ static string bodyBgColor;
 
 static void updateBgColor(const std::string *);
 
-// to generate the generator for each language element
-static GeneratorFactory *generatorFactory;
+// to generate the formatter for each language element
+static TextStyleFormatterFactory *formatterFactory;
+
+/// where we store possible errors
+static string errorBuffer;
 
 
 
@@ -180,7 +185,7 @@ static GeneratorFactory *generatorFactory;
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 54 "./styleparser.yy"
+#line 59 "./styleparser.yy"
 {
   int tok ; /* command */
   const std::string * string ; /* string : id, ... */
@@ -189,7 +194,7 @@ typedef union YYSTYPE
   KeyList *keylist;
 }
 /* Line 187 of yacc.c.  */
-#line 193 "styleparser.cc"
+#line 198 "styleparser.cc"
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
@@ -202,7 +207,7 @@ typedef union YYSTYPE
 
 
 /* Line 216 of yacc.c.  */
-#line 206 "styleparser.cc"
+#line 211 "styleparser.cc"
 
 #ifdef short
 # undef short
@@ -417,7 +422,7 @@ union yyalloc
 /* YYFINAL -- State number of the termination state.  */
 #define YYFINAL  11
 /* YYLAST -- Last index in YYTABLE.  */
-#define YYLAST   27
+#define YYLAST   24
 
 /* YYNTOKENS -- Number of terminals.  */
 #define YYNTOKENS  18
@@ -483,8 +488,8 @@ static const yytype_int8 yyrhs[] =
       19,     0,    -1,    -1,    20,    -1,    20,    21,    -1,    21,
       -1,    22,    -1,    27,    -1,    -1,    24,    25,    26,    23,
       28,    15,    -1,    24,    16,     9,    -1,     9,    -1,    -1,
-      10,    -1,    12,    -1,    -1,    14,    17,    10,    -1,    14,
-      17,    12,    -1,    13,    10,    15,    -1,    13,    12,    15,
+      10,    -1,    12,    -1,    -1,    13,    17,    10,    -1,    13,
+      17,    12,    -1,    14,    10,    15,    -1,    14,    12,    15,
       -1,    -1,    29,    -1,    29,    16,    30,    -1,    30,    -1,
        3,    -1,     4,    -1,     5,    -1,     6,    -1,     7,    -1,
        8,    -1
@@ -493,9 +498,9 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,    73,    73,    74,    77,    78,    81,    82,    86,    85,
-     113,   119,   127,   128,   129,   132,   133,   134,   137,   138,
-     141,   142,   145,   146,   149,   150,   151,   152,   153,   154
+       0,    83,    83,    84,    87,    88,    91,    92,    96,    95,
+     131,   137,   145,   146,   147,   150,   151,   152,   155,   156,
+     159,   160,   163,   164,   167,   168,   169,   170,   171,   172
 };
 #endif
 
@@ -505,8 +510,8 @@ static const yytype_uint8 yyrline[] =
 static const char *const yytname[] =
 {
   "$end", "error", "$undefined", "BOLD", "ITALICS", "UNDERLINE", "FIXED",
-  "NOTFIXED", "NOREF", "KEY", "COLOR", "BG_COLOR", "STRINGDEF",
-  "BODY_BG_COLOR", "BG_T", "';'", "','", "':'", "$accept", "stylefile",
+  "NOTFIXED", "NOREF", "KEY", "COLOR", "BG_COLOR", "STRINGDEF", "BG_T",
+  "BODY_BG_COLOR", "';'", "','", "':'", "$accept", "stylefile",
   "statements", "statement", "option", "@1", "keylist", "color", "bgcolor",
   "bodybgcolor", "stylevalues", "values", "value", 0
 };
@@ -558,20 +563,20 @@ static const yytype_int8 yydefgoto[] =
 
 /* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
    STATE-NUM.  */
-#define YYPACT_NINF -16
+#define YYPACT_NINF -14
 static const yytype_int8 yypact[] =
 {
-      -8,   -16,     3,    14,    -8,   -16,   -16,   -10,   -16,   -12,
-     -11,   -16,   -16,   -16,   -16,     8,     5,   -16,   -16,   -16,
-       7,   -16,     6,     4,   -16,   -16,   -16,   -16,   -16,   -16,
-     -16,   -16,    10,    11,   -16,   -16,     4,   -16
+       5,   -14,    -9,    16,     5,   -14,   -14,   -10,   -14,   -11,
+       2,   -14,   -14,   -14,   -14,    -4,     7,   -14,   -14,   -14,
+       1,   -14,     3,     4,   -14,   -14,   -14,   -14,   -14,   -14,
+     -14,   -14,     6,     8,   -14,   -14,     4,   -14
 };
 
 /* YYPGOTO[NTERM-NUM].  */
 static const yytype_int8 yypgoto[] =
 {
-     -16,   -16,   -16,    16,   -16,   -16,   -16,   -16,   -16,   -16,
-     -16,   -16,   -15
+     -14,   -14,   -14,    18,   -14,   -14,   -14,   -14,   -14,   -14,
+     -14,   -14,   -13
 };
 
 /* YYTABLE[YYPACT[STATE-NUM]].  What to do in state STATE-NUM.  If
@@ -581,25 +586,25 @@ static const yytype_int8 yypgoto[] =
 #define YYTABLE_NINF -1
 static const yytype_uint8 yytable[] =
 {
-      13,     1,    14,    17,    18,     2,    15,    26,    27,    28,
-      29,    30,    31,     9,    11,    10,    24,    19,    25,    20,
-      12,    37,     0,     0,    22,    35,     0,    36
+      13,     9,    14,    10,    17,    19,    15,    26,    27,    28,
+      29,    30,    31,    24,     1,    25,    11,    18,    22,     2,
+      20,    35,    12,    37,    36
 };
 
-static const yytype_int8 yycheck[] =
+static const yytype_uint8 yycheck[] =
 {
-      10,     9,    12,    15,    15,    13,    16,     3,     4,     5,
-       6,     7,     8,    10,     0,    12,    10,     9,    12,    14,
-       4,    36,    -1,    -1,    17,    15,    -1,    16
+      10,    10,    12,    12,    15,     9,    16,     3,     4,     5,
+       6,     7,     8,    10,     9,    12,     0,    15,    17,    14,
+      13,    15,     4,    36,    16
 };
 
 /* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
    symbol of state STATE-NUM.  */
 static const yytype_uint8 yystos[] =
 {
-       0,     9,    13,    19,    20,    21,    22,    24,    27,    10,
+       0,     9,    14,    19,    20,    21,    22,    24,    27,    10,
       12,     0,    21,    10,    12,    16,    25,    15,    15,     9,
-      14,    26,    17,    23,    10,    12,     3,     4,     5,     6,
+      13,    26,    17,    23,    10,    12,     3,     4,     5,     6,
        7,     8,    28,    29,    30,    15,    16,    30
 };
 
@@ -1108,6 +1113,62 @@ yydestruct (yymsg, yytype, yyvaluep)
 
   switch (yytype)
     {
+      case 9: /* "KEY" */
+#line 76 "./styleparser.yy"
+	{
+	if ((yyvaluep->string))
+	  delete (yyvaluep->string);
+};
+#line 1123 "styleparser.cc"
+	break;
+      case 10: /* "COLOR" */
+#line 76 "./styleparser.yy"
+	{
+	if ((yyvaluep->string))
+	  delete (yyvaluep->string);
+};
+#line 1131 "styleparser.cc"
+	break;
+      case 11: /* "BG_COLOR" */
+#line 76 "./styleparser.yy"
+	{
+	if ((yyvaluep->string))
+	  delete (yyvaluep->string);
+};
+#line 1139 "styleparser.cc"
+	break;
+      case 12: /* "STRINGDEF" */
+#line 76 "./styleparser.yy"
+	{
+	if ((yyvaluep->string))
+	  delete (yyvaluep->string);
+};
+#line 1147 "styleparser.cc"
+	break;
+      case 24: /* "keylist" */
+#line 76 "./styleparser.yy"
+	{
+	if ((yyvaluep->keylist))
+	  delete (yyvaluep->keylist);
+};
+#line 1155 "styleparser.cc"
+	break;
+      case 25: /* "color" */
+#line 76 "./styleparser.yy"
+	{
+	if ((yyvaluep->string))
+	  delete (yyvaluep->string);
+};
+#line 1163 "styleparser.cc"
+	break;
+      case 26: /* "bgcolor" */
+#line 76 "./styleparser.yy"
+	{
+	if ((yyvaluep->string))
+	  delete (yyvaluep->string);
+};
+#line 1171 "styleparser.cc"
+	break;
 
       default:
 	break;
@@ -1415,32 +1476,40 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 73 "./styleparser.yy"
+#line 83 "./styleparser.yy"
     { /* allow empty files */ }
     break;
 
   case 8:
-#line 86 "./styleparser.yy"
+#line 96 "./styleparser.yy"
     {
-                 printSequence( (yyvsp[(1) - (3)].keylist) ) ;
-                 printMessage_noln( ": " ) ;
-                 printMessage_noln( ((yyvsp[(2) - (3)].string) ? *(yyvsp[(2) - (3)].string) : "") ) ;
-                 printMessage_noln( " bg: " ) ;
-                 printMessage_noln( ((yyvsp[(3) - (3)].string) ? *(yyvsp[(3) - (3)].string) : "") ) ;
+                 //printSequence( $1 ) ;
+                 //printMessage_noln( ": " ) ;
+                 //printMessage_noln( ($2 ? *$2 : "") ) ;
+                 //printMessage_noln( " bg: " ) ;
+                 //printMessage_noln( ($3 ? *$3 : "") ) ;
              }
     break;
 
   case 9:
-#line 94 "./styleparser.yy"
+#line 104 "./styleparser.yy"
     {
                KeyType key;
                KeyList *keylist = (yyvsp[(1) - (6)].keylist);
                StyleConstantsPtr stylevalues = StyleConstantsPtr((yyvsp[(5) - (6)].styleconstants));
                for (KeyList::const_iterator it = keylist->begin(); it != keylist->end(); ++it) {
                 key = *it;
-                if (!generatorFactory->createGenerator(key, ((yyvsp[(2) - (6)].string) ? *(yyvsp[(2) - (6)].string) : ""), ((yyvsp[(3) - (6)].string) ? *(yyvsp[(3) - (6)].string) : ""), stylevalues)) {
-                  parseStyleError(key);
-                  yyerror("already defined");
+                if (!formatterFactory->createFormatter(key, ((yyvsp[(2) - (6)].string) ? *(yyvsp[(2) - (6)].string) : ""), ((yyvsp[(3) - (6)].string) ? *(yyvsp[(3) - (6)].string) : ""), stylevalues)) {
+                  errorBuffer = "already defined " + *it;
+                  //yyerror(alreadydef);
+
+                  delete keylist;
+                  if ((yyvsp[(2) - (6)].string))
+                   delete (yyvsp[(2) - (6)].string);
+                  if ((yyvsp[(3) - (6)].string))
+                   delete (yyvsp[(3) - (6)].string);
+
+                  YYERROR;
                 }
                }
                delete keylist;
@@ -1452,7 +1521,7 @@ yyreduce:
     break;
 
   case 10:
-#line 114 "./styleparser.yy"
+#line 132 "./styleparser.yy"
     {
               (yyvsp[(1) - (3)].keylist)->push_back(*(yyvsp[(3) - (3)].string));
               (yyval.keylist) = (yyvsp[(1) - (3)].keylist);
@@ -1461,7 +1530,7 @@ yyreduce:
     break;
 
   case 11:
-#line 120 "./styleparser.yy"
+#line 138 "./styleparser.yy"
     {
               (yyval.keylist) = new KeyList;
               (yyval.keylist)->push_back(*(yyvsp[(1) - (1)].string));
@@ -1470,98 +1539,98 @@ yyreduce:
     break;
 
   case 12:
-#line 127 "./styleparser.yy"
+#line 145 "./styleparser.yy"
     { (yyval.string) = 0; }
     break;
 
   case 13:
-#line 128 "./styleparser.yy"
+#line 146 "./styleparser.yy"
     { (yyval.string) = (yyvsp[(1) - (1)].string);}
     break;
 
   case 14:
-#line 129 "./styleparser.yy"
+#line 147 "./styleparser.yy"
     { (yyval.string) = (yyvsp[(1) - (1)].string); }
     break;
 
   case 15:
-#line 132 "./styleparser.yy"
+#line 150 "./styleparser.yy"
     { (yyval.string) = 0; }
     break;
 
   case 16:
-#line 133 "./styleparser.yy"
+#line 151 "./styleparser.yy"
     { (yyval.string) = (yyvsp[(3) - (3)].string);}
     break;
 
   case 17:
-#line 134 "./styleparser.yy"
+#line 152 "./styleparser.yy"
     { (yyval.string) = (yyvsp[(3) - (3)].string); }
     break;
 
   case 18:
-#line 137 "./styleparser.yy"
+#line 155 "./styleparser.yy"
     { updateBgColor((yyvsp[(2) - (3)].string)); }
     break;
 
   case 19:
-#line 138 "./styleparser.yy"
+#line 156 "./styleparser.yy"
     { updateBgColor((yyvsp[(2) - (3)].string)); }
     break;
 
   case 20:
-#line 141 "./styleparser.yy"
-    { (yyval.styleconstants) = 0 ; printMessage( " (no options) " ) ; }
+#line 159 "./styleparser.yy"
+    { (yyval.styleconstants) = 0 ; }
     break;
 
   case 21:
-#line 142 "./styleparser.yy"
-    { (yyval.styleconstants) = (yyvsp[(1) - (1)].styleconstants); printMessage(""); }
+#line 160 "./styleparser.yy"
+    { (yyval.styleconstants) = (yyvsp[(1) - (1)].styleconstants); }
     break;
 
   case 22:
-#line 145 "./styleparser.yy"
+#line 163 "./styleparser.yy"
     { (yyval.styleconstants) = (yyvsp[(1) - (3)].styleconstants); (yyval.styleconstants)->push_back((yyvsp[(3) - (3)].flag)) ; }
     break;
 
   case 23:
-#line 146 "./styleparser.yy"
+#line 164 "./styleparser.yy"
     { (yyval.styleconstants) = new StyleConstants; (yyval.styleconstants)->push_back((yyvsp[(1) - (1)].flag)); }
     break;
 
   case 24:
-#line 149 "./styleparser.yy"
-    { printMessage_noln( " - bold" ) ; (yyval.flag) = ISBOLD ; }
+#line 167 "./styleparser.yy"
+    { (yyval.flag) = ISBOLD ; }
     break;
 
   case 25:
-#line 150 "./styleparser.yy"
-    { printMessage_noln( " - italics" ) ; (yyval.flag) = ISITALIC ; }
+#line 168 "./styleparser.yy"
+    { (yyval.flag) = ISITALIC ; }
     break;
 
   case 26:
-#line 151 "./styleparser.yy"
-    { printMessage_noln( " - underline" ) ; (yyval.flag) = ISUNDERLINE ; }
+#line 169 "./styleparser.yy"
+    { (yyval.flag) = ISUNDERLINE ; }
     break;
 
   case 27:
-#line 152 "./styleparser.yy"
-    { printMessage_noln( " - fixed" ) ; (yyval.flag) = ISFIXED ; }
+#line 170 "./styleparser.yy"
+    { (yyval.flag) = ISFIXED ; }
     break;
 
   case 28:
-#line 153 "./styleparser.yy"
-    { printMessage_noln( " - notfixed" ) ; (yyval.flag) = ISNOTFIXED ; }
+#line 171 "./styleparser.yy"
+    { (yyval.flag) = ISNOTFIXED ; }
     break;
 
   case 29:
-#line 154 "./styleparser.yy"
-    { printMessage_noln( " - noref" ) ; (yyval.flag) = ISNOREF ; }
+#line 172 "./styleparser.yy"
+    { (yyval.flag) = ISNOREF ; }
     break;
 
 
 /* Line 1267 of yacc.c.  */
-#line 1565 "styleparser.cc"
+#line 1634 "styleparser.cc"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1775,52 +1844,57 @@ yyreturn:
 }
 
 
-#line 157 "./styleparser.yy"
+#line 175 "./styleparser.yy"
 
 
 string current_file;
 
 void
-parseStyles(const string &path, const string &name, GeneratorFactory *genFactory,
+parseStyles(const string &path, const string &name, TextStyleFormatterFactory *genFactory,
            string &bodyBgColor_)
 {
-  generatorFactory = genFactory;
+  formatterFactory = genFactory;
+  errorBuffer = "";
+  int result = 1;
+  line = 1;
 
   // opens the file for yylex
   stylesc_in = open_data_file_stream(path, name);
 
-  current_file = (path.size() ? path + "/" : "") + name;
-
-  printMessage_noln( "Parsing ", cerr ) ;
-  printMessage_noln (current_file, cerr);
-  printMessage( " file ...", cerr ) ;
+  if (contains_path(name))
+    current_file = name;
+  else
+    current_file = (path.size() ? path + "/" : "") + name;
 
   bodyBgColor = "";
 
-  yyparse() ;
+  result = yyparse() ;
 
   bodyBgColor_ = bodyBgColor;
 
-  printMessage( "Parsing done!", cerr ) ;
   fclose(stylesc_in);
 
   // free scanner memory
   stylesc_lex_destroy();
+  
+  if (result != 0 || errorBuffer.size()) {
+  	throw ParserException(errorBuffer, current_file, line);
+  }
 }
 
 void
 yyerror( char *s )
 {
-  parseStyleError(s);
+  errorBuffer = s;
 }
 
-void parseStyleError(const std::string &error, bool exit)
+void yyerror(const string &s) {
+  yyerror(s.c_str());
+}
+
+void parseStyleError(const std::string &error)
 {
-	if (exit)
-  		exitError(current_file, line, error);
-  	else {
-  		printError(current_file, line, error);
-  	}
+	yyerror(error);
 }
 
 void updateBgColor(const std::string *c)
